#!/usr/bin/python
# -*- coding: utf-8 -*-

# Importamos las librerias necesarias
import sys
import Adafruit_DHT
import MySQLdb
import os
import time

# Ademas del propio programa, se pasaran otros cuatro argumentos al programa:
# 1) El tipo de sensor con el que trabajaremos, en nuestro caso debe ser el valor '11', haciendo alusion al sensor DHT-11
# 2) Pin GPIO en el que se conecta el sensor DHT-11, en nuestro caso esta conectaco en el 17
# 3) El valor de la temperatura maxima soportada pr el sistema, a partir de este valor se pondran en marcha los mecanismos de actuacion
# 4) El valor de histeresis, una vez que se activa la actuacion del sistema ante una temperatura excesiva, empleamos este valor para que la actuacion prosiga hasta alcanzar 
#    el valor de T maxima menos histeresis. De esta forma evitaremos que el sistema active y desactive los mecanismos de actuacion constantemente
sensor_args = { '11': Adafruit_DHT.DHT11,
                '22': Adafruit_DHT.DHT22,
                '2302': Adafruit_DHT.AM2302 }
if len(sys.argv) == 5 and sys.argv[1] in sensor_args:
    sensor = sensor_args[sys.argv[1]]
    pin = sys.argv[2]
    temperatura_maxima = sys.argv[3]
    histeresis_superior = sys.argv[4]
else:
    print('sintaxis: sudo ./Adafruit_DHT.py [11|22|2302] GPIOpin T_max Histeresis')
    print('ejemplo: sudo ./Adafruit_DHT.py 11 17 30 3 - Lee del sensor DHT11 conectado al GPIO 17, con una temperatura maxima de 30 grados y un valor de histeresis de 3')
    sys.exit(1)

# Intenta tomar una lectura del sensor. Emplea el metodo read_retry, el cual se volvera a activar hasta 15 veces para obtener una lectura del sensor (esperando 2s entre cada intento)
humidity, temperature = Adafruit_DHT.read_retry(sensor, pin)

# Hay que tener en cuenta que en ocasiones no se obtendra la lectura y los resultados seran nulos. Esto es debido a que Linux no puede garantizar el tiempo de llamadas para 
# leer el sensor. Si esto sucede, derebermos intentarlo de nuevo
if humidity is not None and temperature is not None:
    print('Temperatura={0:0.1f}º  Humedad={1:0.1f}%'.format(temperature, humidity))
    print "Temperatura maxima: ",temperatura_maxima
    print "Histeresis superior: ",histeresis_superior
    
   # Aqui termina la primera parte del programa teniendo la temperatura y la humedad en las variables: temperature y humidity. Las imprime junto a los valores de histereis y Tmaxima
   # Ahora pasamos a la segunda funcion del programa: se van a guardar estos valores en la BD

    # Establecemos la conexion con la base de datos
    bd = MySQLdb.connect("localhost","root","0000","BD_TFG" )
    # Preparamos el cursor que nos va a ayudar a realizar las operaciones con la base de datos
    cursor = bd.cursor()
    # Preparamos el query SQL para insertar un registro en la BD
    sql = "INSERT INTO sensor_temperatura (id_muestra, temperatura, humedad, fecha) VALUES (NULL, %r, %r, CURRENT_TIMESTAMP)" % (temperature,humidity)
    try:
       # Ejecutamos el comando
       cursor.execute(sql)
       # Efectuamos los cambios en la base de datos
       bd.commit()
    except:
       # Si se genero algun error revertamos la operacion
       bd.rollback()

    # Aqui ya hemos metido los valores de la Temperatura y Humedad en la Base de Datos y pasamos a la tercera funcion del programa...
    # Ahora vamos hacer que el programa tome (en funcion de la Temperatura) una decision sobre si activar o no los mecanismos de actuacion (activar alarma, activar regulador 
    # de temperatura y enviar alerta via Telegram)

    # Descomentaremos la siguiente linea (en pruebas)  para asignar un valor de temperatura extremo y forzar al sistema para que active los mecanismos de actuacion
    #temperature=50

    # Si la temperatura es superior a la maxima permitida, se ponen en marcha los mecanismos de actuacion
    if temperature > int(temperatura_maxima):
       print "Temperatura Alta"
       # Para activar la alarma:
       os.system("sudo python /home/pi/Actuadores/alarmaON.py")
       # Para activar el regulador de temperatura:
       os.system("sudo python /home/pi/Actuadores/reguladorON.py")
       # Para enviar la alerta automaticamente:
       os.system("/home/pi/Scripts_Alertas/send-telegram.sh Ejemplo 'MENSAJE AUTOMATICO: TEMPERATURA ELEVADA ("+str(temperature)+"ºC)'")
    # Si no...
    else:
       # Si la temperatura ya ha descendido tanto que es menor que el valor resultante de la resta entre la temperatura maxima permitida y el valor de histeresis, entonces ya 
       # se pueden desactivar los mecanismos de respuesta. Como vemos, los mecanismos no se detienen nada mas bajar del valor de temperatura maxima permitida, ya que en ese 
       # caso lo que sucederia es que nada mas activarse el regulador de temperatura, esta descenderia un poco inmediatamente, y el regulador se desactivaria, pero al momento
       # la temperatura volveria a subir y deberia accionarse de nuevo, entrando en un bucle. De ahi la importancia de la histeresis 
       if temperature < ( int(temperatura_maxima) - int(histeresis_superior) ):
          # Para desactivar la alarma:
          os.system("sudo python /home/pi/Actuadores/alarmaOFF.py")
          # Para apagar el regulador de temperatura:
          os.system("sudo python /home/pi/Actuadores/reguladorOFF.py")          

    # Nos desconectamos de la base de datos
    bd.close()
	
else:
    print('Fallo en la lectura. Vuelva a intentarlo.')
    sys.exit(1)
