#!/usr/bin/python

# Importamos las librerias necesarias
import sys
import Adafruit_DHT
import MySQLdb
import os
import time

# Ademas del propio programa, se pasaran otros dos argumentos al programa:
# 1) El tipo de sensor con el que trabajaremos, en nuestro caso debe ser el valor '11', haciendo alusion al sensor DHT-11
# 2) Pin GPIO en el que se conecta el sensor DHT-11, en nuestro caso esta conectaco en el 17
sensor_args = { '11': Adafruit_DHT.DHT11,
                '22': Adafruit_DHT.DHT22,
                '2302': Adafruit_DHT.AM2302 }
if len(sys.argv) == 3 and sys.argv[1] in sensor_args:
    sensor = sensor_args[sys.argv[1]]
    pin = sys.argv[2]
else:
    print('sintaxis: sudo ./Adafruit_DHT.py [11|22|2302] GPIOpin')
    print('ejemplo: sudo ./Adafruit_DHT.py 11 17 - Lee del sensor DHT11 conectado al GPIO 17')
    sys.exit(1)

# Intenta tomar una lectura del sensor. Emplea el metodo read_retry, el cual se volvera a activar hasta 15 veces para obtener una lectura del sensor (esperando 2s entre cada intento)
humidity, temperature = Adafruit_DHT.read_retry(sensor, pin)

# Hay que tener en cuenta que en ocasiones no se obtendra la lectura y los resultados seran nulos. Esto es debido a que Linux no puede garantizar el tiempo de llamadas para
# leer el sensor. Si esto sucede, derebermos intentarlo de nuevo
if humidity is not None and temperature is not None:
    print('Temperatura={0:0.1f}*  Humedad={1:0.1f}%'.format(temperature, humidity))
    
    # Aqui termina la primera parte del programa teniendo la temperatura y la humedad en las variables: temperature y humidity. Se imprimen por pantalla (util para pruebas)
    # Ahora pasamos a la otra funcion del programa: se van a guardar estos valores en la BD

    # Establecemos la conexion con la base de datos
    bd = MySQLdb.connect("localhost","root","0000","BD_TFG" )
    # Preparamos el cursor que nos va a ayudar a realizar las operaciones con la base de datos
    cursor = bd.cursor()
    # Preparamos el query SQL para insertar un registro en la tabla muestreo de la BD
    sql = "INSERT INTO muestreo (id_muestra, temperatura, humedad, fecha) VALUES (NULL, %r, %r, CURRENT_TIMESTAMP)" % (temperature,humidity)
    try:
       # Ejecutamos el comando
       cursor.execute(sql)
       # Efectuamos los cambios en la base de datos
       bd.commit()
    except:
       # Si se genero algun error revertamos la operacion
       bd.rollback()

    # Nos desconectamos de la base de datos
    bd.close()
  
else:
    print('Fallo en la lectura. Vuelva a intentarlo.')
    sys.exit(1)
