<?php
include ("../acceso/seguridad.php");  //verifica que el usuario está correctamente identificado;
include ("../controladores/controladorAccesoBD.php");  // nos conectamos a la Base de Datos

require('/var/www/html/fpdf16/fpdf.php'); //se incluye el fichero de la clase que nos permitirá generar documentos PDF desde PHP: FPDF versión 16

class PDF extends FPDF{
	//cabecera de página
	function Header(){
		//logo
		$this->Image('/var/www/html/img/logo_raspy.png',10,8,33);
		//establece la fuente: familia (arial), estilo (bold) y tamaño (15)
		$this->SetFont('Arial','B',15);
		//movernos a la derecha
		$this->Cell(100);
		//título
		$this->Cell(30,30,'Sistema de seguridad y monitorización basado en Raspberry Pi',0,0,'C');
		//salto de línea
		$this->Ln(40);
	}
	
	//pie de página
	function Footer(){
		//posición: a 1,5 cm del final
		$this->SetY(-15);
		//arial italic 8
		$this->SetFont('Arial','I',8);
		//número de página
		$this->Cell(0,10,'Página '.$this->PageNo().'/{nb}',0,0,'C');
	}
	
	//función para crear la tabla del informe
	function TablaBasica($cabecera){
    	//cabecera
    	foreach($cabecera as $col) //los datos de cabecera recibidos serán los títulos de las columnas
    	$this->Cell(32,7,$col,1);  //sintaxis Cell: ancho de celda, alto de celda, cadena impresa y borde (0: sin marco, 1:con marco)
    	$this->Ln();
    	$this->Cell(32,5,"TEMP. (ºC)",1);
		/*Si el checkbox de temperatura que se seleccionó en informes.php está marcado, se va a rellenar la fila de la tabla correspondiente a la 
		temperatura con los datos calculados en estadisticas.php (temperatura máxima, mínima, media, desviación estándar y coeficiente de variación) 
		que han sido pasados mediante variables de sesión*/
		if ($_SESSION['compruebaT']){
			$this->Cell(32,5,$_SESSION['Tmax'],1);
		}else{
			$this->Cell(32,5,"-",1);
		}
		if ($_SESSION['compruebaT']){
	  		$this->Cell(32,5,$_SESSION['Tmin'],1);
		}else{
			$this->Cell(32,5,"-",1);
		}
		if ($_SESSION['compruebaT']){
	  		$this->Cell(32,5,$_SESSION['Tmed'],1);
		}else{
			$this->Cell(32,5,"-",1);
		}
		if ($_SESSION['compruebaT']){
	  		$this->Cell(32,5,$_SESSION['Tdesviacion'],1);
		}else{
			$this->Cell(32,5,"-",1);
		}
		if ($_SESSION['compruebaT']){
	  		$this->Cell(32,5,$_SESSION['Tcv'],1);
		}else{
			$this->Cell(32,5,"-",1);
		}
		$this->Ln();
		$this->Cell(32,5,"HUMEDAD (%) ",1);
		/*Si el checkbox de humedad que se seleccionó en informes.php está marcado, se va a rellenar la fila de la tabla correspondiente a la 
		humedad con los datos calculados en estadisticas.php (humedad máxima, mínima, media, desviación estándar y coeficiente de variación) 
		que han sido pasados mediante variables de sesión*/
		if ($_SESSION['compruebaH']){
			$this->Cell(32,5,$_SESSION['Hmax'],1);
		}else{
			$this->Cell(32,5,"-",1);
		}
		if ($_SESSION['compruebaH']){
			$this->Cell(32,5,$_SESSION['Hmin'],1);
		}else{
			$this->Cell(32,5,"-",1);
		}
		if ($_SESSION['compruebaH']){
			$this->Cell(32,5,$_SESSION['Hmed'],1);
		}else{
			$this->Cell(32,5,"-",1);
		}
		if ($_SESSION['compruebaH']){
			$this->Cell(32,5,$_SESSION['Hdesviacion'],1);
		}else{
			$this->Cell(32,5,"-",1);
		}
		if ($_SESSION['compruebaH']){
			$this->Cell(32,5,$_SESSION['Hcv'],1);
		}else{
			$this->Cell(32,5,"-",1);
		}
	}
	
	//función para girar elementos
	function Girar($angulo=0,$x=-1,$y=-1) { 
    	if($x==-1) $x=$this->x; 
    	if($y==-1) $y=$this->y; 
    	if($this->angulo!=0) $this->_out('Q'); 
    	$this->angulo=$angulo; 
    	if($angulo!=0) { 
       	 $angulo*=M_PI/180; 
        	$c=cos($angulo); 
        	$s=sin($angulo); 
        	$cx=$x*$this->k; 
        	$cy=($this->h-$y)*$this->k; 
        	$this->_out(sprintf('q %.5f %.5f %.5f %.5f %.2f %.2f cm 1 0 0 1 %.2f %.2f cm',$c,$s,-$s,$c,$cx,$cy,-$cx,-$cy)); 
    	} 
	}
	
	//función para dibujar el gráfico
	function LineGraph($w, $h, $data, $options='', $colors=null, $maxVal=0, $nbDiv=4){
        /*******************************************
        Explicación de las variables:
        $w = anchura del diagrama
        $h = altura del diagrama
        $data = los datos para el diagrama en forma de un array multidimensional
        $options = las posibles opciones de formato, que incluyen:
            'V' = imprimir divisiones verticales
            'H' = imprimir divisiones horizontales
            'kB' = imprimir el cuadro delimitador alrededor de la leyenda
            'vB' = imprimir el cuadro delimitador alrededor de los valores debajo del gráfico
            'gB' = imprimir el cuadro delimitador alrededor del gráfico
            'dB' = imprimir el cuadro delimitador alrededor del diagrama completo
        $colors = array multidimensional que contiene los valores RGB
        $maxVal = valor máximo del gráfico verticalmente
        $nbDiv = número de las divisiones verticales
        *******************************************/
        $this->SetDrawColor(0,0,0);
        $this->SetLineWidth(0.2);
        $keys = array_keys($data);
        $ordinateWidth = 10;
        $w -= $ordinateWidth;
        $valX = $this->getX()+$ordinateWidth;
        $valY = $this->getY();
        $margin = 1;
        $titleH = 8;
        $titleW = $w;
        $lineh = 5;
        $keyH = count($data)*$lineh;
        $keyW = $w/5;
        $graphValH = 5;
        $graphValW = $w-$keyW-3*$margin;
        $graphH = $h-(3*$margin)-$graphValH;
        $graphW = $w-(2*$margin)-($keyW+$margin);
        $graphX = $valX+$margin;
        $graphY = $valY+$margin;
        $graphValX = $valX+$margin;
        $graphValY = $valY+2*$margin+$graphH;
        $keyX = $valX+(2*$margin)+$graphW;
        $keyY = $valY+$margin+.5*($h-(2*$margin))-.5*($keyH);
        //dibujar el borde del marco del gráfico
        if(strstr($options,'gB')){
            $this->Rect($valX,$valY,$w,$h+32);
        }
        //dibujar el borde del diagrama del gráfico
        if(strstr($options,'dB')){
            $this->Rect($valX+$margin,$valY+$margin,$graphW,$graphH);
        }
        //dibujar el borde de la leyenda del gráfico
        if(strstr($options,'kB')){
            $this->Rect($keyX,$keyY,$keyW,$keyH);
        }
        //define los colores
        if($colors===null){
            $safeColors = array(0,51,102,153,204,225);
            for($i=0;$i<count($data);$i++){
                $colors[$keys[$i]] = array($safeColors[array_rand($safeColors)],$safeColors[array_rand($safeColors)],$safeColors[array_rand($safeColors)]);
            }
        }
        //formar un array con todos los valores de los datos del array multidimensional $data
        $ValArray = array();
        foreach($data as $key => $value){
            foreach($data[$key] as $val){
                $ValArray[]=$val;                    
            }
        }
        //define el valor máximo
        if($maxVal<ceil(max($ValArray))){
            $maxVal = ceil(max($ValArray));
        }
        //dibuja las líneas horizontales
        $vertDivH = $graphH/$nbDiv;
        if(strstr($options,'H')){
            for($i=0;$i<=$nbDiv;$i++){
                if($i<$nbDiv){
                    $this->Line($graphX,$graphY+$i*$vertDivH,$graphX+$graphW,$graphY+$i*$vertDivH);
                } else{
                    $this->Line($graphX,$graphY+$graphH,$graphX+$graphW,$graphY+$graphH);
                }
            }
        }
        //dibuja las líneas verticales
        $horiDivW = floor($graphW/(count($data[$keys[0]])-1));
        if(strstr($options,'V')){
            for($i=0;$i<=(count($data[$keys[0]])-1);$i++){
                if($i<(count($data[$keys[0]])-1)){
                    $this->Line($graphX+$i*$horiDivW,$graphY,$graphX+$i*$horiDivW,$graphY+$graphH);
                } else {
                    $this->Line($graphX+$graphW,$graphY,$graphX+$graphW,$graphY+$graphH);
                }
            }
        }
        //dibuja las líneas del gráfico
        foreach($data as $key => $value){
            $this->setDrawColor($colors[$key][0],$colors[$key][1],$colors[$key][2]);
            $this->SetLineWidth(0.8);
            $valueKeys = array_keys($value);
            for($i=0;$i<count($value);$i++){
                if($i==count($value)-2){
                    $this->Line(
                        $graphX+($i*$horiDivW),
                        $graphY+$graphH-($value[$valueKeys[$i]]/$maxVal*$graphH),
                        $graphX+$graphW,
                        $graphY+$graphH-($value[$valueKeys[$i+1]]/$maxVal*$graphH)
                    );
                } else if($i<(count($value)-1)) {
                    $this->Line(
                        $graphX+($i*$horiDivW),
                        $graphY+$graphH-($value[$valueKeys[$i]]/$maxVal*$graphH),
                        $graphX+($i+1)*$horiDivW,
                        $graphY+$graphH-($value[$valueKeys[$i+1]]/$maxVal*$graphH)
                    );
                }
            }
            //establece la leyenda
            $this->SetFont('Courier','',10);
            if(!isset($n))$n=0;
            $this->Line($keyX+1,$keyY+$lineh/2+$n*$lineh,$keyX+8,$keyY+$lineh/2+$n*$lineh);
            $this->SetXY($keyX+8,$keyY+$n*$lineh);
            $this->Cell($keyW,$lineh,$key,0,1,'L');
            $n++;
        }
        //imprime los valores de abscisas
        foreach($valueKeys as $key => $value){
            if($key==0){
                $this->SetXY($graphValX-13,$graphValY+37);
				$this->SetFont('Times','B',12);$this->Girar(90);
                $this->Cell($lineh,30,$value,0,0,'L');
            } else if($key==count($valueKeys)-1){
                $this->SetXY($graphValX+$graphValW-18,$graphValY+3.5);
				$this->SetFont('Times','B',12);$this->Girar(90);
                $this->Cell($lineh,30,$value,0,0,'R');
            } else {
                $this->SetXY($graphValX+$key*$horiDivW-15,$graphValY+20);
				$this->SetFont('Times','B',12);$this->Girar(90);
                $this->Cell($lineh,30,$value,0,0,'C');
            }
        }
        //imprime los valores de ordenadas
        for($i=0;$i<=$nbDiv;$i++){
            $this->SetXY($graphValX-10,$graphY+($nbDiv-$i)*$vertDivH-3);
			$this->SetFont('Times','B',12);$this->Girar(0);
            $this->Cell(6,8,sprintf('%.1f',$maxVal/$nbDiv*$i),0,0,'R');
        }
        $this->SetDrawColor(0,0,0);
        $this->SetLineWidth(0.2);
    }	
}


//INICIO DEL PROGRAMA
$pdf = new PDF();		//creación del objeto FPDF con los parametros por defecto: A4, formato alargado y milimetro como unidad
$pdf->AliasNbPages();	//define un alias para el numero de paginas, por defecto {nb}
$pdf->AddPage();		//se añade una pagina
$pdf->SetFont('Times','',12);	//establece la fuente: familia, estilo y tamaño

//se seleccionan y almacenan todas las fechas en las que hay muestra comprendidas entre los momentos de inicio y fin en la variable $ResultadosF
$sql = "SELECT fecha FROM sensor_temperatura WHERE fecha BETWEEN '" .$_SESSION['Inicio'] ."' AND '" .$_SESSION['Fin'] ."'"; 
$ResultadosF = mysql_query($sql);
//se seleccionan y almacenan todas las muestras de temperatura comprendidas entre los momentos de inicio y fin en la variable $ResultadosT
$sql = "SELECT temperatura FROM sensor_temperatura WHERE fecha BETWEEN '" .$_SESSION['Inicio'] ."' AND '" .$_SESSION['Fin'] ."'"; 
$ResultadosT = mysql_query($sql);
//se seleccionan y almacenan todas las muestras de humedad comprendidas entre los momentos de inicio y fin en la variable $ResultadosH
$sql = "SELECT humedad FROM sensor_temperatura WHERE fecha BETWEEN '" .$_SESSION['Inicio'] ."' AND '" .$_SESSION['Fin'] ."'";   
$ResultadosH = mysql_query($sql);

$i=0;
//en $arrayTemperatura almacenaremos los resultados de las muestras de temperatura junto con la fecha de la muestra
$arrayTemperatura = array ();
while (mysql_result($ResultadosF,$i) != NULL){
	$arrayTemperatura[mysql_result($ResultadosF,$i)] = mysql_result($ResultadosT,$i);
	$i++;
}
$i=0;
//en $arrayHumedad almacenaremos los resultados de las muestras de humedad junto con la fecha de la muestra
$arrayHumedad = array();
while (mysql_result($ResultadosF,$i) != NULL){
	$arrayHumedad[mysql_result($ResultadosF,$i)] = mysql_result($ResultadosH,$i);
	$i++;
}

//si el usuario sólo seleccionó el checkbox humedad en informes.php los datos ($data) con los que se generará el gráfico serán sólo referentes a la humedad
//si el usuario sólo seleccionó el checkbox Tª en informes.php los datos ($data) con los que se generará el gráfico serán sólo referentes a la Tª
//si el usuario seleccionó el checkbox Tª y humedad en informes.php los datos ($data) con los que se generará el gráfico serán referentes a la Tª y humedad
if ( ($_SESSION['compruebaH']=='Humedad') and ($_SESSION['compruebaT']!='Temperatura') ){
	$data = array('Humedad' => $arrayHumedad);
	$pdf->Cell(0,10,$_SESSION['compruebaT'],0,1);
	$pdf->Cell(0,10,$_SESSION['compruebaH'],0,1);
}else{
	if ( ($_SESSION['compruebaT']=='Temperatura') and ($_SESSION['compruebaH']!='Humedad') ){
		$data = array('Temperatura' => $arrayTemperatura);
		$pdf->Cell(0,10,$_SESSION['compruebaT'],0,1);
		$pdf->Cell(0,10,$_SESSION['compruebaH'],0,1);
	}else{
		$data = array('Temperatura' => $arrayTemperatura, 'Humedad' => $arrayHumedad);
	}
}

//se definen los colores con los que representaremos la temperatura y la humedad
$colors = array(
    'Temperatura' => array(255,0,0),
    'Humedad' => array(114,171,237)
);

//generamos la gráfica llamando a la función LineGraph
$pdf->LineGraph(190,100,$data,'VHkBvBgBdB',$colors,6,3);
	
$pdf->Ln(150);
$pdf->SetFont('Times','',12);	//establece la fuente: familia, estilo y tamaño	

//definimos la cabecera de la tabla y la generamos llamando a la función TablaBasica
$cabecera=array(' ','MÁXIMO','MÍNIMO','MEDIA','DESVIACIÓN','C.VARIACIÓN');
$pdf->TablaBasica($cabecera);

//El parametro 'f' guarda el fichero en un fichero local del servidor con el nombre especificado: $pdf->Output('/home/pi/contenedorPDF/mipdf.pdf','f');
//El parametro 'd' envia el fichero al navegador y fuerza la descarga del fichero con el nombre especificado 
//El parametro 'i' envía el fichero al navegador y permite una previsualizacion
$pdf->Output('miPdf.pdf','i');

mysql_close($bdconex); //nos desconectamos de la base de datos
?>